.. _contributor-guide-index:

Contributing
============

Ways to Contribute
------------------

*fluxus* is maintained by the ARTKIT team at BCG X. We welcome contributions from the
community.

There are many ways to contribute, including:

- Create issues for bugs or feature requests
- Address an open issue
- Add or improve unit tests
- Create tutorials
- Improve documentation

For major contributions, please reach out to the ARTKIT team in advance
(ARTKIT@bcg.com).

Please refer to the
`ARTKIT contributor guide <https://bcg-x-official.github.io/artkit/contributor_guide/index.html>`_
for more detailed information on how to contribute to this project. All instructions
that refer to the ARTKIT repository generally also apply to this *fluxus* repository.
